==> tmail-0.10.2.tar.gz: tmail-0.10.2/lib/tmail/address.rb <==
#
# address.rb
#
#   Copyright (c) 1998-2002 Minero Aoki <aamine@loveruby.net>
#
#   This program is free software.
#   You can distribute/modify this program under the terms of
#   the GNU Lesser General Public License version 2 or later.
#

require 'tmail/encode'
require 'tmail/parser'


module TMail

  class Address

    include TextUtils

    def Address.parse( str )
      Parser.parse :ADDRESS, str
    end

    def address_group?
      false
    end

    def initialize( local, domain )
      local.each do |s|
        raise SyntaxError, 'empty word in local' if s.empty?
      end
      if domain then
        domain.each do |s|
          raise SyntaxError, 'empty word in domain' if s.empty?
        end
      end
      @local = local
      @domain = domain
      @name   = nil
      @routes = []
    end

    attr_reader :name

    def name=( str )
      @name = str
      @name = nil if str and str.empty?
    end

    alias phrase  name
    alias phrase= name=

    attr_reader :routes
    alias route routes    # obsolete

    def inspect
      "#<#{type} #{address}>"
    end

    def local
      @local.collect {|i| quote_atom(i) }.join('.')
    end

    def domain
      @domain and join_domain(@domain)
    end

    def spec
      s = local()
      if d = domain() then
        s << '@' << d
      end
      s
    end

    #def spec=( str )
    #  tmp = str.split( '@', 2 )
    #  @local  = tmp[0].split('.')
    #  @domain = tmp[1].split('.')
    #end

    alias address  spec
    #alias address= spec=
    alias addr     spec
    #alias addr=    spec=


    def ==( other )
      other.respond_to? :spec and self.spec == other.spec
    end

    alias eql? ==

    def hash
      @local.hash ^ @domain.hash
    end

    def dup
      obj = type.new( @local.dup, @domain.dup )
      obj.name = @name.dup if @name
      obj.routes.replace @routes
      obj
    end


    include StrategyInterface

    def accept( strategy, dummy = nil )
      spec_p = (not @name and @routes.empty?)

      if @name then
        strategy.phrase @name
        strategy.space
      end
      tmp = spec_p ? '' : '<'
      unless @routes.empty? then
        tmp << @routes.collect {|i| '@' + i }.join(',') << ':'
      end
      tmp << address
      tmp << '>' unless spec_p
      strategy.meta tmp
      strategy.lwsp ''
    end

  end



  class AddressGroup

    include Enumerable

    def address_group?
      true
    end

    def initialize( name, addrs )
      @name = name
      @addresses = addrs
    end

    attr_reader :name
    
    def ==( other )
      # other.respond_to? :name      and @name      == other.name       and
      other.respond_to? :addresses and @addresses == other.addresses
    end

    alias eql? ==

    def hash
      collect {|i| i.hash }.hash
    end

    def []( idx )
      @addresses[idx]
    end

    def size
      @addresses.size
    end

    def empty?
      @addresses.empty?
    end

    def each( &block )
      @addresses.each( &block )
    end

    def to_a
      @addresses.dup
    end

    alias to_ary to_a

    def include?( a )
      @addresses.include? a
    end

    def flatten
      set = []
      @addresses.each do |a|
        if a.respond_to? :flatten then
          set.concat a.flatten
        else
          set.push a
        end
      end
      set
    end

    def each_address( &block )
      flatten.each( &block )
    end

    def add( a )
      @addresses.push a
    end

    alias push add
    
    def delete( a )
      @addresses.delete a
    end

    include StrategyInterface

    def accept( strategy, dummy = nil )
      strategy.phrase @name
      strategy.meta ':'
      strategy.space
      first = true
      each do |mbox|
        if first then
          first = false
        else
          strategy.meta ','
        end
        strategy.space
        mbox.accept strategy
      end
      strategy.meta ';'
      strategy.lwsp ''
    end

  end

end   # module TMail

==> tmail-0.10.3.tar.gz: tmail-0.10.3/lib/tmail/address.rb <==
#
# address.rb
#
#   Copyright (c) 1998-2002 Minero Aoki <aamine@loveruby.net>
#
#   This program is free software.
#   You can distribute/modify this program under the terms of
#   the GNU Lesser General Public License version 2 or later.
#

require 'tmail/encode'
require 'tmail/parser'


module TMail

  class Address

    include TextUtils

    def Address.parse( str )
      Parser.parse :ADDRESS, str
    end

    def address_group?
      false
    end

    def initialize( local, domain )
      local.each do |s|
        raise SyntaxError, 'empty word in local' if s.empty?
      end
      if domain then
        domain.each do |s|
          raise SyntaxError, 'empty word in domain' if s.empty?
        end
      end
      @local = local
      @domain = domain
      @name   = nil
      @routes = []
    end

    attr_reader :name

    def name=( str )
      @name = str
      @name = nil if str and str.empty?
    end

    alias phrase  name
    alias phrase= name=

    attr_reader :routes

    def inspect
      "#<#{type} #{address}>"
    end

    def local
      @local.collect {|i| quote_atom(i) }.join('.')
    end

    def domain
      @domain and join_domain(@domain)
    end

    def spec
      s = local()
      if d = domain() then
        s << '@' << d
      end
      s
    end

    alias address  spec


    def ==( other )
      other.respond_to? :spec and self.spec == other.spec
    end

    alias eql? ==

    def hash
      @local.hash ^ @domain.hash
    end

    def dup
      obj = type.new( @local.dup, @domain.dup )
      obj.name = @name.dup if @name
      obj.routes.replace @routes
      obj
    end


    include StrategyInterface

    def accept( strategy, dummy = nil )
      spec_p = (not @name and @routes.empty?)

      if @name then
        strategy.phrase @name
        strategy.space
      end
      tmp = spec_p ? '' : '<'
      unless @routes.empty? then
        tmp << @routes.collect {|i| '@' + i }.join(',') << ':'
      end
      tmp << address
      tmp << '>' unless spec_p
      strategy.meta tmp
      strategy.lwsp ''
    end

  end



  class AddressGroup

    include Enumerable

    def address_group?
      true
    end

    def initialize( name, addrs )
      @name = name
      @addresses = addrs
    end

    attr_reader :name
    
    def ==( other )
      other.respond_to? :to_a and @addresses == other.to_a
    end

    alias eql? ==

    def hash
      collect {|i| i.hash }.hash
    end

    def []( idx )
      @addresses[idx]
    end

    def size
      @addresses.size
    end

    def empty?
      @addresses.empty?
    end

    def each( &block )
      @addresses.each( &block )
    end

    def to_a
      @addresses.dup
    end

    alias to_ary to_a

    def include?( a )
      @addresses.include? a
    end

    def flatten
      set = []
      @addresses.each do |a|
        if a.respond_to? :flatten then
          set.concat a.flatten
        else
          set.push a
        end
      end
      set
    end

    def each_address( &block )
      flatten.each( &block )
    end

    def add( a )
      @addresses.push a
    end

    alias push add
    
    def delete( a )
      @addresses.delete a
    end

    include StrategyInterface

    def accept( strategy, dummy = nil )
      strategy.phrase @name
      strategy.meta ':'
      strategy.space
      first = true
      each do |mbox|
        if first then
          first = false
        else
          strategy.meta ','
        end
        strategy.space
        mbox.accept strategy
      end
      strategy.meta ';'
      strategy.lwsp ''
    end

  end

end   # module TMail
